==> zio-aws-macie2_2.12-5.20.42.1-sources.jar: zio/aws/macie2/model/SuppressDataIdentifier.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class SuppressDataIdentifier(
    id: Optional[__string] = Optional.Absent,
    `type`: Optional[zio.aws.macie2.model.DataIdentifierType] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.SuppressDataIdentifier = {
    import SuppressDataIdentifier.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.SuppressDataIdentifier
      .builder()
      .optionallyWith(id.map(value => value: java.lang.String))(_.id)
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.SuppressDataIdentifier.ReadOnly =
    zio.aws.macie2.model.SuppressDataIdentifier.wrap(buildAwsValue())
}
object SuppressDataIdentifier {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.SuppressDataIdentifier
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.SuppressDataIdentifier =
      zio.aws.macie2.model.SuppressDataIdentifier(
        id.map(value => value),
        `type`.map(value => value)
      )
    def id: Optional[__string]
    def `type`: Optional[zio.aws.macie2.model.DataIdentifierType]
    def getId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("id", id)
    def getType: ZIO[Any, AwsError, zio.aws.macie2.model.DataIdentifierType] =
      AwsError.unwrapOptionField("type", `type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.SuppressDataIdentifier
  ) extends zio.aws.macie2.model.SuppressDataIdentifier.ReadOnly {
    override val id: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.id())
      .map(value => value: __string)
    override val `type`: Optional[zio.aws.macie2.model.DataIdentifierType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.`type`())
        .map(value => zio.aws.macie2.model.DataIdentifierType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.SuppressDataIdentifier
  ): zio.aws.macie2.model.SuppressDataIdentifier.ReadOnly = new Wrapper(impl)
}

==> zio-aws-macie2_3-7.28.26.1-sources.jar: zio/aws/macie2/model/SuppressDataIdentifier.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class SuppressDataIdentifier(
    id: Optional[__string] = Optional.Absent,
    `type`: Optional[zio.aws.macie2.model.DataIdentifierType] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.SuppressDataIdentifier = {
    import SuppressDataIdentifier.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.SuppressDataIdentifier
      .builder()
      .optionallyWith(id.map(value => value: java.lang.String))(_.id)
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.SuppressDataIdentifier.ReadOnly =
    zio.aws.macie2.model.SuppressDataIdentifier.wrap(buildAwsValue())
}
object SuppressDataIdentifier {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.SuppressDataIdentifier
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.SuppressDataIdentifier =
      zio.aws.macie2.model.SuppressDataIdentifier(
        id.map(value => value),
        `type`.map(value => value)
      )
    def id: Optional[__string]
    def `type`: Optional[zio.aws.macie2.model.DataIdentifierType]
    def getId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("id", id)
    def getType: ZIO[Any, AwsError, zio.aws.macie2.model.DataIdentifierType] =
      AwsError.unwrapOptionField("type", `type`)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.SuppressDataIdentifier
  ) extends zio.aws.macie2.model.SuppressDataIdentifier.ReadOnly {
    override val id: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.id())
      .map(value => value: __string)
    override val `type`: Optional[zio.aws.macie2.model.DataIdentifierType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.`type`())
        .map(value => zio.aws.macie2.model.DataIdentifierType.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.SuppressDataIdentifier
  ): zio.aws.macie2.model.SuppressDataIdentifier.ReadOnly = new Wrapper(impl)
}
